package com.zd.chemical.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zd.chemical.mapper.HxpClassifyConfigMapper;
import com.zd.chemical.domain.HxpClassifyConfig;
import com.zd.chemical.service.IHxpClassifyConfigService;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author zd
 * @date 2022-06-23
 */
@Service
public class HxpClassifyConfigServiceImpl implements IHxpClassifyConfigService
{
    @Autowired
    private HxpClassifyConfigMapper hxpClassifyConfigMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public HxpClassifyConfig selectHxpClassifyConfigById(Long id)
    {
        return hxpClassifyConfigMapper.selectHxpClassifyConfigById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param hxpClassifyConfig 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<HxpClassifyConfig> selectHxpClassifyConfigList(HxpClassifyConfig hxpClassifyConfig)
    {
        return hxpClassifyConfigMapper.selectHxpClassifyConfigList(hxpClassifyConfig);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param hxpClassifyConfig 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertHxpClassifyConfig(HxpClassifyConfig hxpClassifyConfig)
    {
        return hxpClassifyConfigMapper.insertHxpClassifyConfig(hxpClassifyConfig);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param hxpClassifyConfig 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateHxpClassifyConfig(HxpClassifyConfig hxpClassifyConfig)
    {
        return hxpClassifyConfigMapper.updateHxpClassifyConfig(hxpClassifyConfig);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteHxpClassifyConfigByIds(Long[] ids)
    {
        return hxpClassifyConfigMapper.deleteHxpClassifyConfigByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteHxpClassifyConfigById(Long id)
    {
        return hxpClassifyConfigMapper.deleteHxpClassifyConfigById(id);
    }
}
